
animateChecked = true;
spinChecked = true;
informationChecked = true;
backgroundChecked = true;
inspectChecked = false;

modelSpin = true;

-- http://us.battle.net/forums/en/wow/topic/8569600188
local animations = {
    0, -- Idle
    67, -- Hi
    80,
    26, 4, 84, 124, 0, 120, 0, 119, 0,
 5, 0, 69, 0, 66, 0, 68, 0, 70, 0, 74, 0, 75 }
local animationIndex = 1;
local animationUpdateInterval = 2.2; -- How often the OnUpdate code will run (in seconds)
local animationSinceLastUpdate = 0.0;

local unitid = nil;
local frameBorderSize = 18;
local mouseFacing = 0;
local modelScale = 1;
local cursorX = 0;
local cursorY = 0;
local isDraging = false;

local backFile = "Interface\\Glues\\LoadingScreens\\LoadScreenZulGurub"
local backNone = "Interface\\DialogFrame\\UI-DialogBox-Background"; -- "Interface\\Tooltips\\UI-Tooltip-Background";
local edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border"; -- "Interface\\Tooltips\\UI-Tooltip-Border";
local backdrop = {
    bgFile = backFile,
    edgeFile = edgeFile,
    tile = false, tileSize = 16, edgeSize = 24,
    insets = { left = 8, right = 8, top = 8, bottom = 8 }
}

local onInspecting = false;
local items = {};
local slots = {
    "HeadSlot", "NeckSlot", "ShoulderSlot", "BackSlot", "ChestSlot", "ShirtSlot", "TabardSlot", "WristSlot",
    "HandsSlot", "WaistSlot", "LegsSlot", "FeetSlot", "Finger0Slot", "Finger1Slot", "Trinket0Slot", "Trinket1Slot",
    "MainHandSlot", "SecondaryHandSlot"
}

-----------------------
-- KEYBOARD BINDINGS
-----------------------
BINDING_HEADER_INSPECTOR = "Inspector"
BINDING_NAME_INSPECTOR_INSPECT = "Inspect"

function Inspector_OnLoad(self)
    local frame = Inspector;
    frame:RegisterEvent("ADDON_LOADED");
    frame:RegisterEvent("PLAYER_TARGET_CHANGED");

    frame:RegisterForDrag("LeftButton", "RightButton");

    frame:SetScript("OnEvent", Inspector_OnEvent);
    frame:SetScript("OnUpdate", Inspector_OnUpdate);
    frame:SetScript("OnMouseDown", Inspector_OnMouseDown);
    frame:SetScript("OnMouseUp", Inspector_OnMouseUp);
    frame:SetScript("OnMouseWheel", Inspector_OnMouseWheel);
    frame:SetScript("OnDragStart", Inspector_OnDragStart);
    frame:SetScript("OnDragStop", Inspector_OnDragStop);
    --MainFrame:SetScript("OnDragStop", function() MainFrame_OnDragStop(); end);

    tinsert(UISpecialFrames, "Inspector"); -- Hide by ESC Key.
    tinsert(UISpecialFrames, "InspectorConfigFrame"); -- Hide by ESC Key.
end

function Inspector_OnEvent(self, event, ...)
    if (event == "ADDON_LOADED") then
        Inspector_AddonLoaded();
    elseif (event == "PLAYER_TARGET_CHANGED") then
        Inspector_PlayerTargetChanged();
    elseif (event == "INSPECT_READY") then
        Inspector_InspectReady();
    end
end

function Inspector_PlayerTargetChanged()
    if (UnitExists("target")) then
        unitid = "target";
        Inspector_PlayerModel:SetUnit(unitid);

        if Inspector:IsVisible() then
            Inspector_Hide();
            Inspector_Show();
            --Inspector_ShowUnitInfo();
            --BlizzardInspectUI_Show();
        end
        animationIndex = 1;
    else
        --Inspector_Hide();
    end
end

function Inspector_Inspect_OnPress()
    if (Inspector:IsVisible()) then
    --if (DressUpFrame:IsVisible()) then
        Inspector_Hide();
    else
        if (not UnitExists("target")) then
            unitid = "player";
            Inspector_PlayerModel:SetUnit(unitid);
        end
        Inspector_Show();
    end
end

function Inspector_OnMouseDown(self, button)
    --print("OnMouseDown");
    cursorX, cursorY = GetCursorPosition();
    if (button == "LeftButton") then
        mouseFacing = 1; -- Model Rotation Start.
    end
    isDraging = false;
end

function Inspector_OnMouseUp(self, button)
    --print("OnMouseUp");
    local cx, cy = GetCursorPosition();
    if (cursorX == cx and cursorY == cy) then
        if (not isDraging) then
            Inspector_Hide();
        end
    else
        isDraging = true;
    end
    mouseFacing = 0; -- Model Rotation End.
end

function Inspector_OnMouseWheel(self, delta)
    local model = Inspector_PlayerModel;
    local scale = 0.02;
    if (delta == -1) then
        modelScale = modelScale - scale;
        if (modelScale < 0.7) then
            modelScale = 0.7;
        end
    else
        modelScale = modelScale + scale;
        if (modelScale > 1.3) then
            modelScale = 1.3;
        end
    end
    model:SetScale(modelScale);
end

function Inspector_OnDragStart()
    --print("OnDragStart");
    if (spinChecked) then
        modelSpin = false;
    end
    mouseFacing = 1;
    isDraging = true;
end

function Inspector_OnDragStop()
    --print("OnDragStop");
    if (spinChecked) then
        modelSpin = true;
    end
    mouseFacing = 0;
end

function Inspector_OnUpdate(self, elapsed)
    local model = Inspector_PlayerModel;

    if (modelSpin) then
        model:SetFacing(model:GetFacing() + elapsed);
    else
        if (mouseFacing == 1) then
            local cx, cy = GetCursorPosition();
            model:SetFacing(model:GetFacing() + ((cx - cursorX) / 50));
            cursorX, cursorY = GetCursorPosition();
        end
    end

    if (animateChecked) then
        -- http://wowwiki.wikia.com/wiki/Using_OnUpdate_correctly
        animationSinceLastUpdate = animationSinceLastUpdate + elapsed;
        if (animationSinceLastUpdate > animationUpdateInterval) then
            local max = table.getn(animations);
            animationIndex = animationIndex + 1;
            if (animationIndex > max) then
                animationIndex = 1;
            end
            model:SetAnimation(animations[animationIndex], 0);
            animationSinceLastUpdate = 0.0;
        end
    else
        --model:SetAnimation(0, 0);
    end

    if (onInspecting) then
        Inspector_InspectReady();
    end
end

function Inspector_Show()
    if (unitid == nil) then
        return;
    end

    local frame = Inspector;
    local back = Inspector_MainFrame;
    local model = Inspector_PlayerModel;
    local invenLeft = Inspector_InventoryFrameLeft;
    local invenRight = Inspector_InventoryFrameRight;

    PlaySound("GAMEDIALOGOPEN", "master"); -- http://wowwiki.wikia.com/wiki/API_PlaySound

    local scale = UIParent:GetEffectiveScale();
    local width = GetScreenWidth() * scale;
    local height = GetScreenHeight() * scale;

    width = width - (width / 2.2);
    height = height - (height / 8);

    frame:SetWidth(width);
    frame:SetHeight(height);
    frame:ClearAllPoints();
    frame:SetPoint("CENTER", "UIParent");

    back:SetWidth(width);
    back:SetHeight(height);
    if (backgroundChecked) then
        Inspector_ShowBackground();
    else
        Inspector_HideBackground();
    end

    --------------
    -- 모델 설정
    --------------
    width = height;
    model:SetWidth(width - frameBorderSize);
    model:SetHeight(height - frameBorderSize);
    model:SetScale(1);

    if (spinChecked) then
        modelSpin = true;
        model:SetFacing(180);
    else
        model:SetFacing(0);
    end

    if (animateChecked) then
        animationIndex = 1;
        model:SetAnimation(0, 0);
    end

    invenLeft:SetHeight(height - 30); -- 아이템 목록 좌측 프레임
    invenRight:SetHeight(height - 30); -- 아이템 목록 우측 프레임

    ShowUIPanel(frame);

    if (informationChecked) then
        Inspector_ShowUnitInfo();
    end

    if CanInspect(unitid) then
        Inspector_ShowInventory();
    else
        Inspector_HideInventory();
    end

    BlizzardInspectUI_Show();
end

function Inspector_Hide()
    if Inspector:IsVisible() then
        PlaySound("GAMEDIALOGCLOSE", "master"); -- http://wowwiki.wikia.com/wiki/API_PlaySound
    end

    HideUIPanel(Inspector);

    Inspector_HideInventory();

    if (InspectorConfig:IsVisible()) then
        HideUIPanel(InspectorConfig);
    end
    BlizzardInspectUI_Hide();
end

function Inspector_ShowUnitInfo()

    local name, realm = UnitName(unitid);

    if (unitid and name) then

        local level = UnitLevel(unitid);
        local factionGroup, factionName = UnitFactionGroup(unitid);

        if (factionGroup ~= nil) then
            --local factionTexture = "Interface\\FriendsFrame\\PlusManz-"..factionGroup..".blp";
            local factionTexture = "Interface\\AddOns\\Inspector\\Textures\\"..factionGroup..".tga";
            Inspector_MainFrame_FactionTexture:SetTexture(factionTexture);
            Inspector_MainFrame_FactionTexture:Show();

            Inspector_MainFrame_InfoBackTexture:Show();

            -- NAME
            Inspector_MainFrame_NameString:SetText(name);
            Inspector_MainFrame_NameString:Show();

            -- LEVEL
            Inspector_MainFrame_LevelString:SetText("Lv."..level);
            Inspector_MainFrame_LevelString:Show();

            -- NPC
            Inspector_MainFrame_NpcBack:Hide();
            Inspector_MainFrame_NpcString:Hide();
        else
            Inspector_MainFrame_FactionTexture:Hide();
            Inspector_MainFrame_InfoBackTexture:Hide();
            Inspector_MainFrame_NameString:Hide();
            Inspector_MainFrame_LevelString:Hide();
            Inspector_MainFrame_GuildString:Hide();

            -- NPC
            Inspector_MainFrame_NpcBack:Show();
            Inspector_MainFrame_NpcString:SetText(name);
            Inspector_MainFrame_NpcString:Show();
        end

        -- GUILD
        local guildName, guildRankName, guildRankIndex = GetGuildInfo(unitid);
        if (guildName) then
            Inspector_MainFrame_GuildString:SetText(guildName);
            Inspector_MainFrame_GuildString:Show();
        else
            Inspector_MainFrame_GuildString:Hide();
        end

        -- CLASS
        local class, classFileName = UnitClass(unitid);
        local classColor = nil;
        if (class ~= nil and class ~= name) then
            --print("class: "..class); -- "마법사"
            --print("classFileName: "..classFileName); -- "MAGE"
            local classTexture = "Interface\\AddOns\\Inspector\\Textures\\"..classFileName..".tga";
            Inspector_MainFrame_ClassTexture:SetTexture(classTexture);
            Inspector_MainFrame_ClassTexture:Show();
            Inspector_MainFrame_ClassBack:Show();

            classColor = RAID_CLASS_COLORS[classFileName];
            Inspector_MainFrame_ClassString:SetText(class);
            Inspector_MainFrame_ClassString:SetTextColor(classColor.r, classColor.g, classColor.b, 1);
            Inspector_MainFrame_ClassString:Show();
        else
            Inspector_MainFrame_ClassTexture:Hide();
            Inspector_MainFrame_ClassBack:Hide();
            Inspector_MainFrame_ClassString:Hide();
        end

        -- RACE
        local race, raceFileName = UnitRace(unitid);
        if (race ~= nil) then
            --print("race: "..race); -- "인간", "판다렌", ...
            --print("raceFileName: "..raceFileName); -- "Human", "Pandaren", ...

            if (raceFileName == "Scourge") then
                raceFileName = "Undead";
            end
            local raceTexture = "Interface\\AddOns\\Inspector\\Textures\\"..raceFileName..".tga";
            Inspector_MainFrame_RaceTexture:SetTexture(raceTexture);
            Inspector_MainFrame_RaceTexture:Show();
            Inspector_MainFrame_RaceBack:Show();

            if (classColor ~= nil) then
                Inspector_MainFrame_RaceString:SetTextColor(classColor.r, classColor.g, classColor.b, 1);
            else
                Inspector_MainFrame_RaceString:SetTextColor(0.9, 0.9, 0.9, 1);
            end
            Inspector_MainFrame_RaceString:SetText(race);
            Inspector_MainFrame_RaceString:Show();
        else
            Inspector_MainFrame_RaceTexture:Hide();
            Inspector_MainFrame_RaceBack:Hide();
            Inspector_MainFrame_RaceString:Hide();
        end

        --local type = UnitCreatureType(unitid);
        --print("type: "..type); -- "인간형", "야수", "정령" ...

        --if UnitCreatureFamily(unitid) then
        --    print(UnitCreatureFamily(unitid));
        --end

        --if UnitClassification(unitid) then
        --    print(UnitClassification(unitid));
        --end
    end
end

function Inspector_HideUnitInfo()
    Inspector_MainFrame_FactionTexture:Hide();
    Inspector_MainFrame_InfoBackTexture:Hide();
    Inspector_MainFrame_NameString:Hide();
    Inspector_MainFrame_LevelString:Hide();
    Inspector_MainFrame_GuildString:Hide();

    Inspector_MainFrame_ClassTexture:Hide();
    Inspector_MainFrame_ClassBack:Hide();
    Inspector_MainFrame_ClassString:Hide();

    Inspector_MainFrame_RaceTexture:Hide();
    Inspector_MainFrame_RaceBack:Hide();
    Inspector_MainFrame_RaceString:Hide();

    Inspector_MainFrame_NpcBack:Hide();
    Inspector_MainFrame_NpcString:Hide();
end

--------------------------------------------------------------
-- 대상("target")의 아이템 목록을 서버에서 제대로 가져왔는 지 체크
-- http://us.battle.net/forums/en/wow/topic/13569416912
--------------------------------------------------------------
function Inspector_InspectReady()
    Inspector:UnregisterEvent("INSPECT_READY");

    onInspecting = false;

    -- first make sure all links are valid (cached)
    -- trying to get a link will cache it, so we check all slots
    for i, v in ipairs(slots) do
        local itemId = GetInventoryItemID(unitid, i);
        local itemLink = GetInventoryItemLink(unitid, i);

        if (itemLink ~= nil) then
            local name, link, quality, level, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemLink);
            if (not link or not level or not texture) then
                onInspecting = true;
                return; -- if any links were missing, come back next frame and try again
            end
        end

        if itemId then
            local name, link, quality, level, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemId);
            if (not link or not level or not texture) then
                onInspecting = true;
                return; -- if any links were missing, come back next frame and try again
            end
        end
    end

    Inspector_RenderInventory();
end

function Inspector_ShowInventory()
    Inspector_InventoryFrameLeft:Show();
    Inspector_InventoryFrameRight:Show();

    -- Loading...
    Inspector_InventoryFrameLeft_Loading:Show();
    Inspector_InventoryFrameRight_Loading:Show();

    -- 샆펴보기 아이콘, 버튼 보이기
    --Inspector_BlizzardInspectTexture:Show();
    --Inspector_BlizzardInspectButton:Show();

    NotifyInspect(unitid); -- Server is queried for inspection
    Inspector:RegisterEvent("INSPECT_READY");
end

function Inspector_RenderInventory()
    --local max = table.getn(slots);

    Inspector_InventoryFrameLeft_Loading:Hide();
    Inspector_InventoryFrameRight_Loading:Hide();

    local parent;
    local point;
    local anchor;
    local itemOffset = 27;
    local iconW = 35;
    local iconH = 35;
    local iconY = 15;
    local iconOffset = 3;
    local nameW = Inspector_InventoryFrameLeft:GetWidth() - 25;
    local nameH = 18;
    local nameAnchorY = -iconH;
    local levelW = 30;
    local levelH = 18;
    local levelAnchorY = -(iconH - levelH);
    local justifyH = "RIGHT";
    local transLevelAnchorY = 0;

    for i, v in ipairs(slots) do
        local slotId, slotTexture, checkRelic = GetInventorySlotInfo(v);

        local itemPointX = 15;
        local nameAnchorX = 0;
        local levelAnchorX = iconW + iconOffset;
        local transPointX = itemPointX + iconW + iconOffset;
        local transLevelAnchorX = (iconW + iconOffset) * 2;

        local item = items[i];

        if (item == nil) then
            -----------------
            -- 빈 슬롯 만들기
            -----------------
            if (i <= 8) then
                parent = Inspector_InventoryFrameLeft; -- UIParent; (전체 화면으로 보여 줄 때)
                point = "TOPRIGHT";
                anchor = "TOPRIGHT";
                justifyH = "RIGHT";
                itemPointX = -itemPointX;
                nameAnchorX = -nameAnchorX;
                levelAnchorX = -levelAnchorX;
                transPointX = -transPointX;
                transLevelAnchorX = -transLevelAnchorX;
            else
                parent = Inspector_InventoryFrameRight; -- UIParent; (전체 화면으로 보여 줄 때)
                point = "TOPLEFT";
                anchor = "TOPLEFT";
                justifyH = "LEFT";

                if (i == 9) then -- 오픈쪽 첫번째 아이템
                    iconY = 15;
                end
            end
            item = CreateFrame("frame", nil, parent); -- 착용 아이템
            item:SetWidth(iconW);
            item:SetHeight(iconH);
            item:SetPoint(point, itemPointX, -iconY);

            item.icon = item:CreateTexture();
            item.icon:SetTexture(slotTexture);
            item.icon:SetAllPoints(item);

            item.name = item:CreateFontString(nil, "OVERLAY", "GameFontNormal");
            item.name:SetParent(item);
            item.name:SetPoint(point, item, anchor, nameAnchorX, nameAnchorY);
            item.name:SetSize(nameW, nameH);
            item.name:SetJustifyH(justifyH);
            item.name:SetWordWrap(false);

            item.level = item:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall");
            item.level:SetParent(item);
            item.level:SetPoint(point, item, anchor, levelAnchorX, levelAnchorY);
            item.level:SetSize(levelW, levelH);
            item.level:SetJustifyH(justifyH);
            item.level:SetTextColor(1, 1, 0.2, 1); -- yellow

            item.trans = CreateFrame("frame", nil, parent); -- 형상변환 아이템
            item.trans:SetWidth(iconW);
            item.trans:SetHeight(iconH);
            item.trans:SetPoint(point, transPointX, -iconY);

            item.trans.icon = item.trans:CreateTexture(nil, "BACKGROUND");
            item.trans.icon:SetAllPoints(item.trans);
            item.trans.icon:SetTexture(slotTexture);

            item.trans.dot = item.trans:CreateTexture(nil, "OVERLAY"); -- 형상변환 아이템 위에 표시되는 도트 아이콘
            item.trans.dot:SetPoint("TOPLEFT", item.trans, "TOPLEFT", -3, -5);
            item.trans.dot:SetSize(22, 22);
            item.trans.dot:SetTexture("Interface\\GossipFrame\\AvailableQuestIcon");

            item.trans.level = item.trans:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall"); -- 아이템 레벨
            item.trans.level:SetParent(item.trans);
            item.trans.level:SetPoint(point, item, anchor, transLevelAnchorX, transLevelAnchorY);
            item.trans.level:SetSize(levelW, levelH);
            item.trans.level:SetJustifyH(justifyH);
            item.trans.level:SetTextColor(1, 0.2, 1, 1); -- pink

            items[i] = item;
        else
            item:SetScript("OnEnter", nil);
            item:SetScript("OnLeave", nil);
            item.icon:SetTexture(slotTexture);
            item.name:SetText("");
            item.level:SetText("");
            item:Show();

            item.trans:SetScript("OnEnter", nil);
            item.trans:SetScript("OnLeave", nil);
            item.trans.icon:SetTexture(slotTexture);
            item.trans.level:SetText("");
            item.trans:Show();
        end

        if (slotId) then
            -- http://us.battle.net/forums/en/wow/topic/13569416912
            -- http://wowprogramming.com/docs/api/GetItemInfo
            local lName, lLink, lQuality, lLevel, lReqLevel, lClass, lSubclass, lMaxStack, lSlot, lTexture, lVendorPrice;
            local iName, iLink, iQuality, iLevel, iReqLevel, iClass, iSubclass, iMaxStack, iSlot, iTexture, iVendorPrice;

            local itemLink = GetInventoryItemLink(unitid, slotId);
            local itemId = GetInventoryItemID(unitid, slotId);

            local newPoint = "TOPLEFT";
            local newAnchor = "TOPLEFT";
            local newLevelAnchorX = iconW + iconOffset;
            local newTransAnchorX = (iconW + iconOffset) * 2;
            if (i <= 8) then
                newPoint = "TOPRIGHT";
                newAnchor = "TOPRIGHT";
                newLevelAnchorX = -newLevelAnchorX;
                newTransAnchorX = -newTransAnchorX;
            end

            if (itemLink) then
                lName, lLink, lQuality, lLevel, lReqLevel, lClass, lSubclass, lMaxStack, lSlot, lTexture, lVendorPrice = GetItemInfo(itemLink);
            else
                item.trans:Hide();
                item.level:SetPoint(newPoint, item, newAnchor, newLevelAnchorX, levelAnchorY); -- 아이템 레벨 위치 변경
            end

            if (itemId) then
                iName, iLink, iQuality, iLevel, iReqLevel, iClass, iSubclass, iMaxStack, iSlot, iTexture, iVendorPrice = GetItemInfo(itemId);
                --print(i..": "..lLink..", "..iLink);

                if (lLink) then
                    item.icon:SetTexture(lTexture);
                    lLink = lLink:gsub("[\[]", "");
                    lLink = lLink:gsub("[\]]", "");
                    item.name:SetText(lLink);

                    if (lLevel == 1) then -- 계승품은 1레벨로 출력된다.
                        lLevel = InspectFrame_ScanItemLevel(lLink);
                    end
                    item.level:SetText(lLevel);

                    item:SetScript("OnEnter", function(self)
                        GameTooltip:SetOwner(self, "ANCHOR_BOTTOMLEFT"); --"ANCHOR_CURSOR");
                        GameTooltip:SetHyperlink(lLink); -- 형상변환 후의 아이넴 정보
                        --GameTooltip:SetInventoryItem(unitid, slotId); -- 형상변환 전의 원래 아이템 정보
                        GameTooltip:Show();
                    end);
                    item:SetScript("OnLeave", function(self)
                        GameTooltip:Hide();
                    end);

                    if (lName == iName or lTexture == iTexture) then
                        item.trans:Hide();
                        item.level:SetPoint(newPoint, item, newAnchor, newLevelAnchorX, levelAnchorY); -- 아이템 레벨 위치 변경
                    else
                        item.trans.icon:SetTexture(iTexture);
                        item.trans.level:SetText(iLevel);

                        item.trans:SetScript("OnEnter", function(self)
                            GameTooltip:SetOwner(self, "ANCHOR_BOTTOMLEFT"); --"ANCHOR_CURSOR");
                            GameTooltip:SetHyperlink(iLink); -- 형상변환 후의 아이넴 정보
                            --GameTooltip:SetInventoryItem(unitid, slotId); -- 형상변환 전의 원래 아이템 정보
                            GameTooltip:Show();
                        end);
                        item.trans:SetScript("OnLeave", function(self)
                            GameTooltip:Hide();
                        end);

                        item.level:SetPoint(newPoint, item, newAnchor, newTransAnchorX, levelAnchorY); -- 아이템 레벨 위치 변경
                    end
                end
            end
        end

        iconY = iconY + iconH + itemOffset;
    end
end

function Inspector_HideInventory()
    local count = table.getn(items);
    if (count > 0) then
        for i, v in ipairs(slots) do
            items[i]:Hide();
            items[i].trans:Hide();
        end
    end

    Inspector_InventoryFrameLeft:Hide();
    Inspector_InventoryFrameRight:Hide();

    -- 샆펴보기 아이콘, 버튼 보이기
    --Inspector_InspectTexture:Hide();
    --Inspector_InspectButton:Hide();
end

function InspectFrame_ScanItemLevel(itemLink)
    local tooltip = CreateFrame("GameTooltip", "InspectFrame_GameTooltip", nil, "GameTooltipTemplate");
    tooltip:SetOwner(UIParent, "ANCHOR_NONE");
    tooltip:SetHyperlink(itemLink);
    tooltip:Show();

    local itemLevel = 0;
    for i = 2, tooltip:NumLines() do
        local text = _G[ tooltip:GetName() .."TextLeft"..i]:GetText();
        if(text and text ~= "") then
            local value = tonumber(text:match(ITEM_LEVEL:gsub( "%%d", "(%%d+)" )));
            if(value) then
                itemLevel = value;
            end
        end
    end
    tooltip:Hide();
    return itemLevel
end

function Inspector_StartAnimation()
    local model = Inspector_PlayerModel;
    model:SetAnimation(26, 0); -- attack stance
end

function Inspector_StopAnimation()
    local model = Inspector_PlayerModel;
    model:SetAnimation(0, 0); -- idle
end

function Inspector_ShowBackground()
    local frame = Inspector_MainFrame;
    local max = table.getn(blps);
    local key = math.random (1, max);
    backdrop.bgFile = "Interface\\Glues\\LoadingScreens\\"..blps[key];
    --backdrop.bgFile = "Interface\\AddOns\\Inspector\\Textures\\Druid_Background.tga";
    backdrop.title = false;
    frame:SetBackdrop(backdrop);
end

function Inspector_HideBackground()
    local frame = Inspector_MainFrame;
    backdrop.bgFile = backNone;
    backdrop.title = true;
    frame:SetBackdrop(backdrop);
    frame:SetBackdropColor(0, 0, 0, 0.7);
end

function BlizzardInspectUI_Show()
    if (inspectChecked and CanInspect(unitid)) then
        InspectUnit(unitid);
    end
end

function BlizzardInspectUI_Hide()
    HideUIPanel(InspectFrame);
end

-- "Config" 버튼 클릭 시
function Inspector_ConfigButton_OnClick()
    ShowUIPanel(InspectorConfig);
end

-- "Inspect" 버튼 클릭 시
function Inspector_BlizzardInspectButton_OnClick()
    if (InspectFrame and InspectFrame:IsVisible()) then
        HideUIPanel(InspectFrame);
    else
        if CanInspect(unitid) then
            InspectUnit(unitid);
        end
    end
end

-- "Close" 버튼 클릭 시
function Inspector_CloseButton_OnClick()
    Inspector_Hide();
end

function Inspector_AddonLoaded()
    if (InspectorSettings) then
        animateChecked = InspectorSettings.animateChecked;
        if (animateChecked == nil) then animateChecked = true; end

        spinChecked = InspectorSettings.spinChecked;
        if (spinChecked == nil) then
            spinChecked = true;
        end
        modelSpin = spinChecked;

        informationChecked = InspectorSettings.informationChecked;
        if (informationChecked == nil) then informationChecked = true; end

        backgroundChecked = InspectorSettings.backgroundChecked;
        if (backgroundChecked == nil) then backgroundChecked = true; end

        inspectChecked = InspectorSettings.inspectChecked;
        if (inspectChecked == nil) then inspectChecked = true; end
    end
end

function Inspector_SaveVariables()
    InspectorSettings = {
        animateChecked = animateChecked,
        spinChecked = spinChecked,
        informationChecked = informationChecked,
        backgroundChecked = backgroundChecked,
        inspectChecked = inspectChecked
    }
end

-- -----------------------------------------------------------------------------------------------
-- https://us.battle.net/support/en/article/download-the-world-of-warcraft-interface-addon-kit
-- -----------------------------------------------------------------------------------------------
blps = {
"LoadScreenArgentDungeon.blp",
"LOADSCREENARGENTRAID.BLP",
"LOADSCREENAUCHINDOUN.BLP",
"LOADSCREENAZJOLNERUB76.BLP",
"LoadScreenAzjolUpperCity.blp",
"LoadScreenBaradinHold.blp",
"LoadScreenBlackrockCaverns.blp",
"LoadScreenBlackrockDepths.blp",
"LoadScreenBlackwingDescentRaid.blp",
"LoadScreenBlackWingLair.blp",
"LoadScreenBladesEdgeArena.blp",
"LoadScreenCave.blp",
"LOADSCREENCAVERNSTIME.BLP",
"LoadScreenChamberBlack.blp",
"LoadScreenChampionsHall.blp",
"LoadScreenDalaranPrison.blp",
"LoadScreenDalaranSewersArena.blp",
"LoadScreenDeadmines.blp",
"LOADSCREENDEATHKNIGHT.BLP",
"LoadScreenDeepholm.blp",
"LOADSCREENDEEPHOLMDUNGEON.BLP",
"LoadScreenDireMaul.blp",
"LoadScreenDrakTharon.blp",
"LoadScreenDungeon.blp",
"LoadScreenEnviroment.blp",
"LoadScreenGilneasBG.blp",
"LoadScreenGilneasBG2.blp",
"LoadScreenGnomeregan.blp",
"LOADSCREENGRIMBATOL.BLP",
"LoadScreenGrimBatolRaid.blp",
"LOADSCREENGUNDRAK.BLP",
"LoadScreenHallofLegends.blp",
"LoadScreenHallsofOrigination.blp",
"LoadScreenHallsofReflection.blp",
"LOADSCREENHELLFIRECITADEL5MAN.BLP",
"LOADSCREENHELLFIRECITADELRAID.BLP",
"LoadScreenHyjal.blp",
"LoadScreenIcecrown5man.blp",
"LoadScreenIcecrownCitadel.blp",
"LOADSCREENISLEOFCONQUEST.BLP",
"LoadScreenKarazhan.blp",
"LOADSCREENMALYGOS.BLP",
"LoadScreenMaraudon.blp",
"LoadScreenMoltenCore.blp",
"LoadScreenMonastery.blp",
"LoadScreenNagrandArenaBattlegrounds.blp",
"LoadScreenNexus70.blp",
"LoadScreenNexus80.blp",
"LoadScreenNorthrendBG.blp",
"LoadScreenOldStrathome.blp",
"LoadScreenOrgrimmarArena.blp",
"LoadScreenPitofSaron.blp",
"LoadScreenRagefireChasm.blp",
"LoadScreenRazorfenDowns.blp",
"LoadScreenRazorfenKraul.blp",
"LoadScreenRubySanctum.blp",
"LoadScreenRuinedCity.blp",
"LoadScreenRuinsofLordaeronBattlegrounds.blp",
"LoadScreenScholomance.blp",
"LOADSCREENSHADOWFANGKEEP.BLP",
"LoadScreenSkywall.blp",
"LoadScreenSkywallRaid.blp",
"LoadScreenStormwindStockade.blp",
"LoadScreenStrathome.blp",
"LoadScreenSunkenTemple.blp",
"LoadScreenSunwell5Man.blp",
"LOADSCREENTEMPESTKEEP.BLP",
"LoadScreenThroneoftheTides.blp",
"LoadScreenTolBarad.blp",
"LoadScreenTwinPeaksBG.blp",
"LOADSCREENULDAMAN.BLP",
"LoadScreenUlduar77.blp",
"LoadScreenUlduar80.blp",
"LOADSCREENULDUARRAID.BLP",
"LoadScreenUldumDungeon.blp",
"LOADSCREENUTGARDE.BLP",
"LoadScreenUtgardePinnecle.blp",
"LoadScreenWailingCaverns.blp",
"LoadScreenWintergrasp.blp",
"LOADSCREENZULAMAN.BLP",
"LoadScreenZulFarrak.blp",
"LoadScreenZulGurub.blp"
}